#!/usr/bin/env python
# _*_ coding:utf-8 _*_
from common_pims.lib.utility import report_path

__author__ = 'jack'

import os, sys
from time import sleep

sys.path.append(os.path.dirname(os.path.dirname(__file__)))
import shutil
# from cases.ussm2 import setting
from openpyxl import load_workbook
from openpyxl.styles import Font, Alignment
from openpyxl.styles.colors import RED, GREEN, DARKYELLOW
# import configparser as cparser
#
# # --------- 读取config.ini配置文件 ---------------
# cf = cparser.ConfigParser()
# cf.read(setting.TEST_CONFIG, encoding='UTF-8')
# name = cf.get("tester", "name")


class WriteExcel():
    """文件写入数据"""

    def __init__(self, fileName,source):
        self.filename = fileName
        self.source = source

        if not os.path.exists(self.filename):
            # 文件不存在，则拷贝模板文件至指定报告目录下
            # shutil.copyfile(setting.SOURCE_FILE, setting.TARGET_FILE)
            shutil.copyfile(self.source,self.filename)
            sleep(1)

        self.wb = load_workbook(self.filename)
        self.ws = self.wb.active


    def write_data(self, row_n, value, name):
        """
        写入测试结果
        :param row_n:数据所在行数
        :param value: 测试结果值
        :param value: 运行人员
        :return: 无
        """
        font_GREEN = Font(name='宋体', color=GREEN, bold=True)
        font_RED = Font(name='宋体', color=RED, bold=True)
        font1 = Font(name='宋体', color=DARKYELLOW, bold=True)
        align = Alignment(horizontal='center', vertical='center')
        # 获数所在行数
        L_n = "L" + str(row_n)
        M_n = "M" + str(row_n)
        if value == "PASS":
            self.ws.cell(row_n, 12, value)
            self.ws[L_n].font = font_GREEN
        if value == "FAIL":
            self.ws.cell(row_n, 12, value)
            self.ws[L_n].font = font_RED
        self.ws.cell(row_n, 13, name)
        self.ws[L_n].alignment = align
        self.ws[M_n].font = font1
        self.ws[M_n].alignment = align
        self.wb.save(self.filename)


    #cxx2022.1.22
    def write_data_1(self, row_n, value, name,time_1,actual_results):
        """
        写入测试结果
        :param row_n:数据所在行数
        :param value: 测试结果值
        :param value: 运行人员
        :return: 无
        """

        font_GREEN = Font(name='宋体', color=GREEN, bold=True)
        font_RED = Font(name='宋体', color=RED, bold=True)
        font1 = Font(name='宋体', color=DARKYELLOW, bold=True)
        align = Alignment(horizontal='center', vertical='center')
        # 获数所在行数
        K_n = "AF" + str(row_n)
        L_n = "AG" + str(row_n)
        M_n = "AH" + str(row_n)
        N_n = "AI" + str(row_n)
        #实际结果
        self.ws.cell(row_n, 32, actual_results)
        self.ws[N_n].font = font1
        self.ws[N_n].alignment = align
        #PASS or FAIL
        if value == "PASS":
            self.ws.cell(row_n, 33, value)
            self.ws[L_n].font = font_GREEN
        if value == "FAIL":
            self.ws.cell(row_n, 33, value)
            self.ws[L_n].font = font_RED
        self.ws.cell(row_n, 34, name)
        self.ws[L_n].alignment = align
        self.ws[M_n].font = font1
        self.ws[M_n].alignment = align
        #time
        self.ws.cell(row_n, 35, time_1)
        self.ws[N_n].font = font1
        self.ws[N_n].alignment = align
        self.wb.save(self.filename)



#定义接口自动化关键字类
import requests
import json
import sys,os
import configparser as cparser
from common_pims.lib.public import TEST_CONFIG


sys.path.append(os.path.dirname(os.path.dirname(__file__)))

class SendRequests():
    """发送请求数据"""
    # 判断请求方式
    def sendRequests(self, s, data,token_1,cookie_2):
        try:
            method = data['method']
            url = data['url']
            #print(url)
            reade_mode = data['type']
            UseCase = data['UseCase']
            #encryption = data['encryption']
            h = data['headers']
            body_1 = data['body']
            par = data['params']
            contain_ch = data['contain_ch']
            ex_type = data['request_data_type']
            file = data['file']
            filename = data['filename']
            filepath = data['filepath']
            filetype = data['filetype']
            file_2 = data['file2']
            filename_2 = data['filename2']
            filepath_2 = data['filepath2']
            filetype_2 = data['filetype2']
            url_token=data['url_token']     #是否需要加token
            cookie_1=data['cookie_1']      #是否需要加cookie
            parametric=data['parametric']   #是否有逻辑关联
            msg = data['msg']
            #是否有逻辑关联
            #print(url_token)
            try:
                if parametric=='Yes':   #cxx220208
                    pass
                else:
                    if url_token == 'Yes':
                       # token_1 =data['token']   # Token的值
                        #token_1 = get_mannjutoken(product_name, lobnumber)  # Token的值
                        url = url + '&mannjuToken='+token_1
                        #print(url)
                    else:
                        url = url
                    if cookie_1=='Yes':
                        cookies=cookie_2
                    else:
                        cookies=None

                    if ex_type == 'File':
                        m_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))  # 获取上两级目录
                        filepath = m_path + '\\file\\' + filepath
                        filepath_2 = m_path + '\\file\\' + filepath_2
                        if file_2 != '':

                            files_1 = {file: (filename, open(filepath, 'rb'), filetype),file_2: (filename_2, open(filepath_2, 'rb'), filetype_2)}

                        else:
                            files_1 = {file: (filename, open(filepath, 'rb'), filetype)}

                    else:
                        files_1 = None



                    #body_1 = body.encode("utf-8").decode("latin1")  #12.30
                    # if (body != '' or body != 'No') and contain_ch == 'Yes':   #12.30
                    if (body_1 != '' and body_1 != 'No'):
                        if contain_ch != 'Yes':  # contain_ch请求中是否包含汉字
                            body_1 = body_1.encode("utf-8").decode("latin1")
                            # str转换为dict
                            body_1 = json.loads(body_1)
                            if reade_mode == 'json':
                                # dict转换为json
                                body_1 = json.dumps(body_1)
                            else:
                                pass
                        else:
                            #pass   #12.30
                            body_1 = body_1.encode("utf-8")
                            body_1 = body_1.decode()
                            try:
                                body_1 = eval(body_1)
                            except:
                                body_1=json.loads(body_1)
                            # try:
                            #     body_1 = eval(body_1)
                            # except:
                            #     body_1=body_1.encode("utf-8").decode("latin1")
                            if reade_mode == 'json':
                                # dict转换为json
                                body_1 = json.dumps(body_1)
                                print(body_1)
                            else:
                                pass
                    else:
                        pass
                    if h != 'No'and h !='':
                        try:
                            # str转换为dict
                            h = json.loads(h)
                        except:
                            h = None
                    else:
                        h = None
                    if par != 'No'and par != '':
                        try:
                            # str转换为dict
                            par = json.loads(par)
                        except:
                            par = None

                    else:
                        par = None

                    # if files_1 !='':
                    #     files=files_1
                    # else:
                    #     files=None
                    print("用例标题：%s" % UseCase)
                    print("请求方式：%s" % method)
                    print("请求url：%s" % url)
                    print("header：%s" % h)
                    print("params：%s" % par)
                    print("body：%s" % body_1)
                    print("文件：%s" % files_1)
                    print("cookie：%s" % cookies)
                    print("验证字段：%s" % msg)

                    res = s.request(method=method, url=url, headers=h, params=par, data=body_1, files=files_1,cookies=cookies,verify=None,auth=None, timeout=None, allow_redirects=True,proxies=None,hooks=None, stream=None, cert=None, json=None)
                    #res=requests.post(url=url,headers=h,data=body_1)
                    return res
            except:
                pass

        except:
            #print('api封装有误')
            pass

    def sendRequests_1(self, s, data,token_1,cookie_2):
        try:
            #2022/4/15
            cf = cparser.ConfigParser()
            TEST_CONFIG_1 = TEST_CONFIG()
            cf.read(TEST_CONFIG_1, encoding='UTF-8')
            ip = cf.get("tester", "ip")
            method = data['method']
            url = ip+data['url']
            UseCase = data['UseCase']
            #print(url)
            reade_mode = data['type']
            #encryption = data['encryption']
            h = data['headers']
            body_1 = data['body']
            par = data['params']
            contain_ch = data['contain_ch']
            ex_type = data['request_data_type']
            file = data['file']
            filename = data['filename']
            filepath = data['filepath']
            filetype = data['filetype']
            file_2 = data['file2']
            filename_2 = data['filename2']
            filepath_2 = data['filepath2']
            filetype_2 = data['filetype2']
            url_token=data['url_token']     #是否需要加token
            cookie_1=data['cookie_1']      #是否需要加cookie
            parametric=data['parametric']   #是否有逻辑关联
            msg = data['msg']
            #是否有逻辑关联
            #print(url_token)
            try:
                if parametric=='Yes':   #cxx220208
                    pass
                else:
                    if url_token == 'Yes':
                       # token_1 =data['token']   # Token的值
                        #token_1 = get_mannjutoken(product_name, lobnumber)  # Token的值
                        url = url + '&mannjuToken='+token_1
                        #print(url)
                    else:
                        url = url
                    if cookie_1=='Yes':
                        cookies=cookie_2
                    else:
                        cookies=None

                    if ex_type == 'File':
                        m_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))  # 获取上两级目录
                        filepath = m_path + '\\file\\' + filepath
                        filepath_2 = m_path + '\\file\\' + filepath_2
                        if file_2 != '':

                            files_1 = {file: (filename, open(filepath, 'rb'), filetype),file_2: (filename_2, open(filepath_2, 'rb'), filetype_2)}

                        else:
                            files_1 = {file: (filename, open(filepath, 'rb'), filetype)}

                    else:
                        files_1 = None



                    #body_1 = body.encode("utf-8").decode("latin1")  #12.30
                    # if (body != '' or body != 'No') and contain_ch == 'Yes':   #12.30
                    if (body_1 != '' and body_1 != 'No'):
                        if contain_ch != 'Yes':  # contain_ch请求中是否包含汉字
                            body_1 = body_1.encode("utf-8").decode("latin1")
                            # str转换为dict
                            body_1 = json.loads(body_1)
                            if reade_mode == 'json':
                                # dict转换为json
                                body_1 = json.dumps(body_1)
                            else:
                                pass
                        else:
                            #pass   #12.30

                            body_1 = body_1.encode("utf-8")
                            body_1 = body_1.decode()
                            try:
                                body_1 = eval(body_1)
                            except:
                                body_1=json.loads(body_1)
                            # try:
                            #     body_1 = eval(body_1)
                            # except:
                            #     body_1=body_1.encode("utf-8").decode("latin1")
                            if reade_mode == 'json':
                                # dict转换为json
                                body_1 = json.dumps(body_1)
                            else:
                                pass
                    else:
                        pass
                    if h != 'No'and h !='':
                        try:
                            # str转换为dict
                            h = json.loads(h)
                        except:
                            h = None
                    else:
                        h = None
                    if par != 'No'and par != '':
                        try:
                            # str转换为dict
                            par = json.loads(par)
                        except:
                            par = None

                    else:
                        par = None

                    # if files_1 !='':
                    #     files=files_1
                    # else:
                    #     files=None
                    print("用例标题：%s" % UseCase)
                    print("请求方式：%s" % method)
                    print("请求url：%s" % url)
                    print("header：%s" % h)
                    print("params：%s" % par)
                    print("body：%s" % body_1)
                    print("文件：%s" % files_1)
                    print("cookie：%s" % cookies)
                    print("验证字段：%s" % msg)

                    res = s.request(method=method, url=url, headers=h, params=par, data=body_1, files=files_1,cookies=cookies,verify=None,auth=None, timeout=None, allow_redirects=True,proxies=None,hooks=None, stream=None, cert=None, json=None)
                    return res
            except:
                pass

        except:
            #print('api封装有误')
            pass





#pfms
    def sendRequests_2(self, s, data,token_1,cookie_2):
        try:
            #2022/4/15
            cf = cparser.ConfigParser()
            TEST_CONFIG_1 = TEST_CONFIG()
            cf.read(TEST_CONFIG_1, encoding='UTF-8')
            ip = cf.get("tester", "ip")
            method = data['method']
            url = ip+data['url']
            UseCase=data['UseCase']

            #print(url)
            reade_mode = data['type']
            #encryption = data['encryption']
            h = data['headers']
            body_1 = data['body']
            par = data['params']
            contain_ch = data['contain_ch']
            ex_type = data['request_data_type']
            file = data['file']
            filename = data['filename']
            filepath = data['filepath']
            filetype = data['filetype']
            file_2 = data['file2']
            filename_2 = data['filename2']
            filepath_2 = data['filepath2']
            filetype_2 = data['filetype2']
            url_token=data['url_token']     #是否需要加token
            cookie_1=data['cookie_1']      #是否需要加cookie
            parametric=data['parametric']   #是否有逻辑关联
            msg = data['msg']
            try:
                timeout=data['timeout']
            except:
                pass
            #是否有逻辑关联
            #print(url_token)
            try:
                if parametric=='Yes':   #cxx220208
                    pass
                else:
                    if url_token == 'Yes':
                       # token_1 =data['token']   # Token的值
                        #token_1 = get_mannjutoken(product_name, lobnumber)  # Token的值
                        url = url + '&mannjuToken='+token_1
                        #print(url)
                    else:
                        url = url
                    if cookie_1=='Yes':
                        cookies=cookie_2
                    else:
                        cookies=None

                    if ex_type == 'File':
                        m_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))  # 获取上两级目录
                        filepath = m_path + '\\file\\' + filepath
                        filepath_2 = m_path + '\\file\\' + filepath_2
                        if file_2 != '':

                            files_1 = {file: (filename, open(filepath, 'rb'), filetype),file_2: (filename_2, open(filepath_2, 'rb'), filetype_2)}

                        else:
                            files_1 = {file: (filename, open(filepath, 'rb'), filetype)}

                    else:
                        files_1 = None



                    #body_1 = body.encode("utf-8").decode("latin1")  #12.30
                    # if (body != '' or body != 'No') and contain_ch == 'Yes':   #12.30
                    if (body_1 != '' and body_1 != 'No'):
                        if contain_ch != 'Yes':  # contain_ch请求中是否包含汉字
                            body_1 = body_1.encode("utf-8").decode("latin1")
                            # str转换为dict
                            body_1 = json.loads(body_1)
                            if reade_mode == 'json':
                                # dict转换为json
                                body_2=body_1
                                body_1=''
                            else:
                                body_2=''
                        else:
                            body_1 = body_1.encode("utf-8")
                            body_1 = body_1.decode()
                            try:
                                body_1 = eval(body_1)
                            except:
                                body_1=json.loads(body_1)
                            if reade_mode == 'json':
                                # dict转换为json
                                #body_1 = json.dumps(body_1)
                                body_2=body_1
                                body_1=''

                            else:
                                body_2 = ''
                    else:
                        body_1 = ''
                        body_2=''
                    if h != 'No'and h !='':
                        try:
                            # str转换为dict
                            h = json.loads(h)
                        except:
                            h = h
                    else:
                        h = None
                    if par != 'No'and par != '':
                        try:
                            # str转换为dict
                            par = json.loads(par)
                        except:
                            par = None

                    else:
                        par = None

                    print("用例标题：%s" % UseCase)
                    print("请求方式：%s" % method)
                    print("请求url：%s" % url)
                    print("headers：%s" % h)
                    print("params：%s" % par)
                    print("body：%s" % body_1)
                    print("body：%s" % body_2)
                    print("文件：%s" % files_1)
                    print("cookie：%s" % cookies)
                    print("验证字段：%s" % msg)

                    res = s.request(method=method, url=url, headers=h, params=par, data=body_1,files=files_1,cookies=cookies,json=body_2,timeout=None,verify=None,auth=None, allow_redirects=True,proxies=None,hooks=None, stream=None, cert=None)
                    #res =  requests.post(url=url, json=body_2, cookies=cookie_2)
                    return res
            except:
                pass

        except:
            #print('api封装有误')
            pass


    def sendRequests_3(self, s, data,token_1,cookie_2):
        try:
            method = data['method']
            url = data['url']
            #print(url)
            reade_mode = data['type']
            #encryption = data['encryption']
            h = data['headers']
            UseCase = data['UseCase']
            # print('-------------')
            # print(h)
            body_1 = data['body']
            par = data['params']
            contain_ch = data['contain_ch']
            ex_type = data['request_data_type']
            file = data['file']
            filename = data['filename']
            filepath = data['filepath']
            filetype = data['filetype']
            file_2 = data['file2']
            filename_2 = data['filename2']
            filepath_2 = data['filepath2']
            filetype_2 = data['filetype2']
            url_token=data['url_token']     #是否需要加token
            cookie_1=data['cookie_1']      #是否需要加cookie
            parametric=data['parametric']   #是否有逻辑关联
            msg=data['msg']
            try:
                timeout=data['timeout']
            except:
                pass

            #是否有逻辑关联
            #print(url_token)
            try:
                if parametric=='Yes':   #cxx220208
                    pass
                else:
                    if url_token == 'Yes':
                       # token_1 =data['token']   # Token的值
                        #token_1 = get_mannjutoken(product_name, lobnumber)  # Token的值
                        url = url + '&mannjuToken='+token_1
                        #print(url)
                    else:
                        url = url

                    if cookie_1=='Yes':
                        cookies=cookie_2
                    else:
                        cookies=None

                    if ex_type == 'File':
                        m_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))  # 获取上两级目录
                        filepath = m_path + '\\file\\' + filepath
                        filepath_2 = m_path + '\\file\\' + filepath_2
                        if file_2 != '':

                            files_1 = {file: (filename, open(filepath, 'rb'), filetype),file_2: (filename_2, open(filepath_2, 'rb'), filetype_2)}

                        else:
                            files_1 = {file: (filename, open(filepath, 'rb'), filetype)}

                    else:
                        files_1 = None



                    #body_1 = body.encode("utf-8").decode("latin1")  #12.30
                    # if (body != '' or body != 'No') and contain_ch == 'Yes':   #12.30
                    if (body_1 != '' and body_1 != 'No'):
                        if contain_ch != 'Yes':  # contain_ch请求中是否包含汉字
                            body_1 = body_1.encode("utf-8").decode("latin1")
                            # str转换为dict
                            body_1 = json.loads(body_1)
                            if reade_mode == 'json':
                                # dict转换为json
                                body_2=body_1
                                body_1=''
                            else:
                                body_2=''
                        else:
                            #pass   #12.30
                            body_1 = body_1.encode("utf-8")
                            body_1 = body_1.decode()
                            try:
                                body_1 = eval(body_1)
                            except:
                                body_1=json.loads(body_1)
                            # body_1=body_1.encode('utf-8').decode('unicode_escape')


                            if reade_mode == 'json':
                                # dict转换为json
                                #body_1 = json.dumps(body_1)
                                body_2=body_1
                                body_1=''

                            else:
                                body_2 = ''
                    else:
                        body_1 = ''
                        body_2=''
                    if h != 'No'and h !='':
                        try:
                            # str转换为dict
                            h = json.loads(h)
                        except:
                            h = h
                    else:
                        h = None
                    if par != 'No'and par != '':
                        try:
                            # str转换为dict
                            par = json.loads(par)
                        except:
                            par = None

                    else:
                        par = None

                    print("用例标题：%s" % UseCase)
                    print("请求方式：%s" % method)
                    print("请求url：%s" % url)
                    print("header：%s" % h)
                    print("params：%s" % par)
                    print("body：%s" % body_1)
                    print("body：%s" % body_2)
                    print("文件：%s" % files_1)
                    print("cookie：%s" % cookies)
                    print("验证字段：%s" % msg)
                    try:
                        print("超时：%s" % timeout)
                    except:
                        pass

                    res = s.request(method=method, url=url, headers=h, params=par, data=body_1,files=files_1,cookies=cookies,json=body_2,verify=None,auth=None, timeout=None, allow_redirects=True,proxies=None,hooks=None, stream=None, cert=None)
                    #res =  requests.post(url=url, json=body_2, cookies=cookie_2)
                    return res
            except:
                pass

        except:
            #print('api封装有误')
            pass



    def sendRequests_4(self, s, data,token_1, cookie_2):
        method = data['method']
        url = data['url']
        # print(url)
        reade_mode = data['type']
        # encryption = data['encryption']
        h = data['headers']
        body_1 = data['body']
        par = data['params']
        contain_ch = data['contain_ch']
        ex_type = data['request_data_type']
        file = data['file']
        filename = data['filename']
        filepath = data['filepath']
        filetype = data['filetype']
        file_2 = data['file2']
        filename_2 = data['filename2']
        filepath_2 = data['filepath2']
        filetype_2 = data['filetype2']
        url_token = data['url_token']  # 是否需要加token
        cookie_1 = data['cookie_1']  # 是否需要加cookie
        parametric = data['parametric']  # 是否有逻辑关联
        msg = data['msg']
        timeout = data['timeout']

        # 是否有逻辑关联
        # print(url_token)
        try:
            if parametric == 'Yes':  # cxx220208
                pass
            else:
                if url_token == 'Yes':
                    # token_1 =data['token']   # Token的值
                    # token_1 = get_mannjutoken(product_name, lobnumber)  # Token的值
                    url = url + '&mannjuToken=' + token_1
                    # print(url)
                else:
                    url = url

                if cookie_1 == 'Yes':
                    cookies = cookie_2
                else:
                    cookies = None

                if ex_type == 'File':
                    m_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))  # 获取上两级目录
                    filepath = m_path + '\\file\\' + filepath
                    filepath_2 = m_path + '\\file\\' + filepath_2
                    if file_2 != '':

                        files_1 = {file: (filename, open(filepath, 'rb'), filetype),
                                   file_2: (filename_2, open(filepath_2, 'rb'), filetype_2)}

                    else:
                        files_1 = {file: (filename, open(filepath, 'rb'), filetype)}

                else:
                    files_1 = None

                # body_1 = body.encode("utf-8").decode("latin1")  #12.30
                # if (body != '' or body != 'No') and contain_ch == 'Yes':   #12.30
                if (body_1 != '' and body_1 != 'No'):
                    if contain_ch != 'Yes':  # contain_ch请求中是否包含汉字
                        body_1 = body_1.encode("utf-8").decode("latin1")
                        # str转换为dict
                        body_1 = json.loads(body_1)
                        if reade_mode == 'json':
                            # dict转换为json
                            body_2 = body_1
                            body_1 = ''
                        else:
                            body_2 = ''
                    else:
                        # pass   #12.30
                        body_1 = body_1.encode("utf-8")
                        body_1 = body_1.decode()
                        try:
                            body_1 = eval(body_1)
                        except:
                            body_1 = json.loads(body_1)
                        # body_1=body_1.encode('utf-8').decode('unicode_escape')


                        if reade_mode == 'json':
                            # dict转换为json
                            # body_1 = json.dumps(body_1)
                            body_2 = body_1
                            body_1 = ''

                        else:
                            body_2 = ''
                else:
                    body_1 = ''
                    body_2 = ''
                if h != 'No' and h != '':
                    try:
                        # str转换为dict
                        h = json.loads(h)
                    except:
                        h = h
                else:
                    h = None
                if par != 'No' and par != '':
                    try:
                        # str转换为dict
                        par = json.loads(par)
                    except:
                        par = None

                else:
                    par = None
        except:
            pass
        print("请求方式：%s" % method)
        print("请求url：%s" % url)
        print("header：%s" % h)
        print("params：%s" % par)
        print("body：%s" % body_1)
        print("body：%s" % body_2)
        print("文件：%s" % files_1)
        print("cookie：%s" % cookies)
        print("验证字段：%s" % msg)
        print("timeout：%s" % timeout)
        # url='http://test.chinasoftinc.com:8996'
        # headers={"mannjuToken":get_mannjutoken("aa",'87515'),"module":"YHR_APP","method":"ehr_saas/web/icss/attOverApplyWithRest/getOverRestApplyShowInfo.welinkEmp","httpMethod":"get"}
        res=requests.get(url,headers=h)
        return res

    def sendRequests_5(self, s, data, token_1, cookie_2):
        method = data['method']
        url = data['url']
        # print(url)
        reade_mode = data['type']
        # encryption = data['encryption']
        h = data['headers']
        body_1 = data['body']
        par = data['params']
        contain_ch = data['contain_ch']
        ex_type = data['request_data_type']
        file = data['file']
        filename = data['filename']
        filepath = data['filepath']
        filetype = data['filetype']
        file_2 = data['file2']
        filename_2 = data['filename2']
        filepath_2 = data['filepath2']
        filetype_2 = data['filetype2']
        url_token = data['url_token']  # 是否需要加token
        cookie_1 = data['cookie_1']  # 是否需要加cookie
        parametric = data['parametric']  # 是否有逻辑关联
        msg = data['msg']
        form = data['form']

        # 是否有逻辑关联
        # print(url_token)
        try:
            if parametric == 'Yes':  # cxx220208
                pass
            else:
                if url_token == 'Yes':
                    # token_1 =data['token']   # Token的值
                    # token_1 = get_mannjutoken(product_name, lobnumber)  # Token的值
                    url = url + '&mannjuToken=' + token_1
                    # print(url)
                else:
                    url = url

                if cookie_1 == 'Yes':
                    cookies = cookie_2
                else:
                    cookies = None

                if ex_type == 'File':
                    m_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))  # 获取上两级目录
                    filepath = m_path + '\\file\\' + filepath
                    filepath_2 = m_path + '\\file\\' + filepath_2
                    if file_2 != '':

                        files_1 = {file: (filename, open(filepath, 'rb'), filetype),
                                   file_2: (filename_2, open(filepath_2, 'rb'), filetype_2)}

                    else:
                        files_1 = {file: (filename, open(filepath, 'rb'), filetype)}

                else:
                    files_1 = None

                # body_1 = body.encode("utf-8").decode("latin1")  #12.30
                # if (body != '' or body != 'No') and contain_ch == 'Yes':   #12.30
                if (body_1 != '' and body_1 != 'No'):
                    if contain_ch != 'Yes':  # contain_ch请求中是否包含汉字
                        body_1 = body_1.encode("utf-8").decode("latin1")
                        # str转换为dict
                        body_1 = json.loads(body_1)
                        if reade_mode == 'json':
                            # dict转换为json
                            body_2 = body_1
                            body_1 = ''
                        else:
                            body_2 = ''
                    else:
                        # pass   #12.30
                        body_1 = body_1.encode("utf-8")
                        body_1 = body_1.decode()
                        try:
                            body_1 = eval(body_1)
                        except:
                            body_1 = json.loads(body_1)
                        # body_1=body_1.encode('utf-8').decode('unicode_escape')


                        if reade_mode == 'json':
                            # dict转换为json
                            # body_1 = json.dumps(body_1)
                            body_2 = body_1
                            body_1 = ''

                        else:
                            body_2 = ''
                else:
                    body_1 = ''
                    body_2 = ''
                if h != 'No' and h != '':
                    try:
                        # str转换为dict
                        h = json.loads(h)
                    except:
                        h = h
                else:
                    h = None
                if par != 'No' and par != '':
                    try:
                        # str转换为dict
                        par = json.loads(par)
                    except:
                        par = None

                else:
                    par = None
        except:
            pass
        m = MultipartEncoder(body_1)
        headers = {
            "Content-Type": m.content_type}
        print("请求方式：%s" % method)
        print("请求url：%s" % url)
        print("header：%s" % headers)
        print("params：%s" % par)
        print("body：%s" % body_1)
        print("body：%s" % body_2)
        print("文件：%s" % files_1)
        print("cookie：%s" % cookies)
        print("验证字段：%s" % msg)

        res = requests.post(url, data=m, headers=headers, cookies=cookies)
        # print(res.text)
        return res


#!/usr/bin/env python
# -*-coding:utf-8 -*-
import configparser as cparser
import datetime
import difflib
import math
import re
import shutil
import time

import os
import zipfile

__author__ = 'jack'

h_time = time.strftime("%H:%M:%S/", time.localtime())
runner = ''


def get_path():
    """
    :return:获取当前工作路径
    """
    return os.getcwd()


def zip_dir(dirname, zipfilename):
    """
    :param dirname: 要打包的文件夹
    :param zipfilename:打包后的zip
    :return:
    """
    filelist = []
    if os.path.isfile(dirname):
        filelist.append(dirname)
    else:
        for root, dirs, files in os.walk(dirname):
            for name in files:
                filelist.append(os.path.join(root, name))
    zf = zipfile.ZipFile(zipfilename, "w", zipfile.zlib.DEFLATED)
    for tar in filelist:
        arcname = tar[len(dirname):]
        zf.write(tar, arcname)
    zf.close()


def report_path():
    """
    测试文件存储路径
    :return: report的path
    """
    cf = cparser.ConfigParser()
    cf.read(get_path() + "/config.ini", encoding="utf-8")
    # print(get_path())
    # product_name = cf.get("product_name", "product_name")
    _report_path = dict(cf.items("report"))['path']
    # if not os.path.exists(_report_path):
    #     os.makedirs(_report_path)
    return _report_path


def target_file_path():
    """
    excel测试用例结果文件
    :return: report的path
    """
    cf = cparser.ConfigParser()
    cf.read(get_path() + "/config.ini", encoding="utf-8")
    print(get_path())
    # product_name = cf.get("product_name", "product_name")
    _report_path = dict(cf.items("report"))['path']
    if not os.path.exists(_report_path):
        os.makedirs(_report_path)
    return _report_path


def delete_file(product_name):
    """
    删除文件../report/product_name/
    :return:
    """
    time.sleep(2)
    if os.path.isdir(report_path() + product_name):
        shutil.rmtree(report_path() + product_name)
        time.sleep(2)
    return "ok"





import smtplib
import time
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
from email.header import Header
from common_pims.lib.newReport import new_report
from time import sleep

# cxx增加   2022.1.22修改
# 定义发送邮件
#def send_mail(new_report_html,new_report_xls,product_name,receiver,sender,username,password,smtpserver,port):
def send_mail(path_xls,path_html,cf,receiver=['cuixiaoxia@chinasofti.com']):
    product_name = cf.get("product_name", "product_name")
    username = cf.get("email","username")  # 发件箱用户名
    password = cf.get("email","password")  # 发件箱密码
    sender = cf.get("email","user")  # 发件人邮箱
    smtpserver = cf.get("email","host_server")  # 发件服务器
    port = cf.get("email","port")  # 端口
    new_report_html = new_report(path_html)
    new_report_xls = new_report(path_xls)

    # 编辑邮件的内容
    #读文件
    f = open(new_report_html, 'rb')  #xml
    mail_body = f.read()
    mail_bod_2 = open(new_report_xls, 'rb').read()  #xlsx
    f.close()
    # 邮件正文是MIMEText
    body = MIMEText(mail_body, 'html', 'utf-8')
    # 邮件对象
    #msg = MIMEMultipart() #-----------
    msg = MIMEMultipart()   #采用related定义内嵌资源的邮件体
    msg['Subject'] = Header(product_name+"自动化测试报告", 'utf-8').encode()#主题
    msg['From'] = Header(u'API自动化 <%s>'%sender)                #发件人
    #msg['To'] = Header(u'test测试发送 <%s>'%receiver)            #收件人
    msg['To'] = ','.join(receiver)
    msg['date'] = time.strftime("%a,%d %b %Y %H:%M:%S %z")
    msg.attach(body)
    # 附件1
    att = MIMEText(mail_body, "base64", "utf-8")
    att["Content-Type"] = "application/octet-stream"
    att["Content-Disposition"] = 'attachment; filename="test_report.html"'  #filename是附件的重新命名
    msg.attach(att)

    #附件2

    att_2 = MIMEText(mail_bod_2, "base64", "utf-8")
    att_2["Content-Type"] = "application/octet-stream"
    att_2["Content-Disposition"] = 'attachment; filename="report.xlsx"'  #filename是附件的重新命名
    msg.attach(att_2)

    # 发送邮件
    try:
        smtp = smtplib.SMTP()    #若163邮箱非SSL,公司邮箱也用这个
        #smtp.set_debuglevel(1)
        smtp.connect(smtpserver)  # 连服务器
        smtp.login(username, password)
    except:
        smtp = smtplib.SMTP_SSL(smtpserver, port)  #如QQ邮件，SSL
        smtp.login(username, password)  # 登录
    smtp.sendmail(sender, msg['To'].split(','), msg.as_string())  # 发送  msg['To'].split(',')可以实现多人发送
    smtp.quit()
    print("邮件已发出！注意查收。")
    sleep(2)






# #!/usr/bin/env python
# # _*_ coding:utf-8 _*_
# __author__ = 'JACK'
#
# import os, sys
#
# sys.path.append(os.path.dirname(os.path.dirname(__file__)))
# from cases.ussm import setting
# import smtplib
# from common.lib.newReport import new_report
# import configparser
# from email.mime.text import MIMEText
# from email.mime.multipart import MIMEMultipart
#
#
# def send_mail(file_new):
#     """
#     定义发送邮件
#     :param file_new:
#     :return: 成功：打印发送邮箱成功；失败：返回失败信息
#     """
#     f = open(file_new, 'rb')
#     mail_body = f.read()
#     f.close()
#     # 发送附件
#     con = configparser.ConfigParser()
#     con.read(setting.TEST_CONFIG, encoding='utf-8')
#     report = new_report(setting.TEST_REPORT)
#     sendfile = open(report, 'rb').read()
#     # --------- 读取config.ini配置文件 ---------------
#     HOST = con.get("user", "HOST_SERVER")
#     SENDER = con.get("user", "FROM")
#     RECEIVER = con.get("user", "TO")
#     USER = con.get("user", "user")
#     PWD = con.get("user", "password")
#     SUBJECT = con.get("user", "SUBJECT")
#
#     att = MIMEText(sendfile, 'base64', 'utf-8')
#     att["Content-Type"] = 'application/octet-stream'
#     att.add_header("Content-Disposition", "attachment", filename=("gbk", "", report))
#
#     msg = MIMEMultipart('related')
#     msg.attach(att)
#     msgtext = MIMEText(mail_body, 'html', 'utf-8')
#     msg.attach(msgtext)
#     msg['Subject'] = SUBJECT
#     msg['from'] = SENDER
#     msg['to'] = RECEIVER
#
#     try:
#         server = smtplib.SMTP()
#         server.connect(HOST)
#         server.starttls()
#         server.login(USER, PWD)
#         server.sendmail(SENDER, RECEIVER, msg.as_string())
#         server.quit()
#         print("邮件发送成功！")
#     except Exception as  e:
#         print("失败: " + str(e))




# cxx增加
import datetime
import xlrd,random
import os
from time import sleep
import time
from common_pims.lib.utility import *
from selenium import webdriver
from selenium.webdriver.chrome.options import Options


def get_shijianchuo_p():
    nowtime = datetime.datetime.now()
    # 格式化当前时间,获取时间戳
    strtime = datetime.datetime.strftime(nowtime, "%Y/%m/%d %H:%M:%S")
    return strtime


#读取Excel表格中passed数量   2022.1.22修改
def num_pa(file_path,num_result):
    global p
    try:
        book = xlrd.open_workbook(file_path, 'rb')  # 打开Excel
        sheet = book.sheet_by_index(0)  # 获取第几个sheet页数据
        p=0
        for i in range(1, sheet.nrows):  # sheet.nrows获取列表中的每一行
            #获取32行值
            z=sheet.cell_value(i, num_result)  # 文件类型2
            if z=='PASS':
                p=p+1
        return p
    except:
        pass


#获取行数
def gain_excel_nrows( num_table,file_path):
    #filepath = 'D:\\Interface_automation\\ussm\\test\\file\\data.xls'
    # module_path = os.path.abspath('..')  # 获取上一级目录
    # #filepath = module_path + '/file/data.xls'
    # filepath = module_path + file_path
    date = xlrd.open_workbook(file_path, "r")
    table = date.sheets()[num_table]  # 打开第几张表
    num_rows = table.nrows  # 获取表的行数
    return num_rows


#判断文件夹是否存在，不存在，则新建
def determine_directory(path):
    #path='D:\Interface_automation\API\\report\\aagc'
    os.path.exists(path)
    try:
        os.mkdir(path)
        sleep(1)
    except:
        pass
    sleep(1)

def bj():
    m_path = os.path.abspath(os.path.join(os.getcwd(), "."))  # 获取本级目录
    # print(m_path)
    return m_path

def lj():
    m_path = os.path.abspath(os.path.join(os.getcwd(), ".."))  # 获取上级目录
    # print(m_path)
    return m_path

def sj():
    m_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))  # 获取上两级目录
    # print(m_path)
    return m_path

def html_time():
    html_time_1 = time.strftime("_%Y-%m-%d-%H-%M-%S", time.localtime())
    return html_time_1

def time1():
    time_11 = time.strftime("%Y/%m/%d", time.localtime())
    return time_11

def report_p(product_name):
    # report_pa = report_path() + product_name + "\excelReport\\"
    report_pa=os.path.join(report_path() + product_name, "excelReport")
    return report_pa

def TARGET_FILE_dir(product_name):
    TARGET_FILE_d = report_path() + product_name +  "\excelReport"
    #print(TARGET_FILE_d)
    return TARGET_FILE_d

def TARGET_FILE(product_name,source_file):
    TARGET_F = os.path.join(report_p(product_name), product_name + html_time() + source_file)
    # TARGET_F=os.path.join(report_path() + product_name, "excelReport", product_name + html_time + source_file)
    return TARGET_F

def SOURCE_FILE(source_file):
    SOURCE_FILE = os.path.join(bj(), source_file)
    return SOURCE_FILE

def TEST_CONFIG():
    TEST_CONF= os.path.join(bj(), "config.ini")
    return TEST_CONF


def html_file(product_name):
    html_fi=report_path() + product_name + '\\' + product_name + html_time() + ".html"
    return html_fi

def html_FILE_dir(product_name):
    html_FILE_d=report_path() + product_name
    # print(html_FILE_d)
    return html_FILE_d


def time_1():
    for i in range(50):
        time_1 = datetime.datetime.strftime(datetime.datetime.now(), "%m%d%H")
        return time_1
def random_n():
    random_n = ''.join(random.sample('123456789abcdefghigklmnopqrstuvwxyzABCDEFGHIGKLMNOPQRESTUVWXYZ', 3))
    return random_n
def random_num():
    time_11=time_1()
    random_n1=random_n()
    random_num = time_11 + random_n1
    return random_num
def time_2():
    time_2 = datetime.datetime.strftime(datetime.datetime.now(), "%Y%m%d%H%M%S")
    return time_2
def random_nu():
    random_nu = ''.join(random.sample('0123456789', 4))
    return random_nu
def random_nu1():
    random_nu = ''.join(random.sample('0123456789', 4))
    return random_nu

def random_three():
    random_three = ''.join(random.sample('0123456789', 3))
    return random_three

def random_z():
    random_z = ''.join(random.sample('ABCDEFGHIGKLMNOPQRESTUVWXYZ', 4))
    return random_z
def pems_random():
    time_211=time_2()
    random_nu11=random_nu()
    random_z11=random_z()
    pems_random = time_211 + random_nu11 + random_z11
    return pems_random
def time_st():
    time_st = int(time.time() * 1000)
    #print(time_st)
    return time_st
def time_ots():
    time_ots = str(int(time.time()))
    #print(time_ots)
    return time_ots

def time_r():
    time_r = datetime.datetime.strftime(datetime.datetime.now(), "%Y-%m-%d")
    return time_r

def time_ny():
    time_r = datetime.datetime.strftime(datetime.datetime.now(), "%Y-%m")
    return time_r



def time_nyyc():
    time_r = datetime.datetime.strftime(datetime.datetime.now(), "%Y%m")
    return time_r

def time_nyrsfmyc():
    time_r = datetime.datetime.strftime(datetime.datetime.now(), "%Y-%m-%d %H:%M:%S")
    return time_r

def time_nyc():
    time_r = datetime.datetime.strftime(datetime.datetime.now(), "%Y")
    return time_r


# 定义10天后时间
def get_shijian_ten():
    # 获取当前时间
    today = datetime.datetime.now()
    # 计算偏移量
    offset = datetime.timedelta(days=10)
    # 获取想要的日期的时间
    re_date = (today + offset).strftime('%Y-%m-%d')
    return re_date

# 定义1天后时间
def get_time_one():
    # 获取当前时间
    today = datetime.datetime.now()
    datedayOfWeek=today.weekday()
    if datedayOfWeek<4 or datedayOfWeek > 5:
        # 计算偏移量
        offset = datetime.timedelta(days=1)
        # 获取想要的日期的时间
        re_date = (today + offset).strftime('%Y-%m-%d')
    else:
        # 计算偏移量
        offset = datetime.timedelta(days=3)
        # 获取想要的日期的时间
        re_date = (today + offset).strftime('%Y-%m-%d')
    return re_date



def get_next_month_otherday(month_str=None):
    # 获取下下一个月的第28天     get_next_month_otherday
    '''
    param: month_str 月份，2021-04
    '''
    # return: 格式 %Y-%m-%d
    if not month_str:
        # month_str = datetime.now().strftime('%Y-%m')
        month_str=datetime.datetime.now().strftime('%Y-%m')
    year, month = int(month_str.split('-')[0]), int(month_str.split('-')[1])
    if month == 11:
        year += 1
        month = '01'
    elif month == 12:
        year += 1
        month = '02'
    else:
        month += 2
    return '{}-{}-28'.format(year, month)

def time_month():
    #获取当前月
    time_month = datetime.datetime.strftime(datetime.datetime.now(), "%Y-%m")
    return time_month
   #print(time_month())

def get_next_month(month_str=None):
    # 获取下一个月
    '''
    param: month_str 月份，2021-04
    '''
    # return: 格式 %Y-%m-%d
    if not month_str:
        # month_str = datetime.now().strftime('%Y-%m')
        month_str=datetime.datetime.now().strftime('%Y-%m')
    year, month = int(month_str.split('-')[0]), int(month_str.split('-')[1])
    if month == 12:
        year += 1
        month = '01'
    else:
        month += 1
    return '{}-{}'.format(year, month)

def get_next2_month(month_str=None):
    # 获取下下一个月
    '''
    param: month_str 月份，2021-04
    '''
    # return: 格式 %Y-%m-%d
    if not month_str:
        # month_str = datetime.now().strftime('%Y-%m')
        month_str=datetime.datetime.now().strftime('%Y-%m')
    year, month = int(month_str.split('-')[0]), int(month_str.split('-')[1])
    #if month ==11:
    if month == 11:
        year += 1
        month = '01'
    elif month == 12:
        year += 1
        month = '02'
    else:
        month += 2
    return '{}-{}'.format(year, month)



def time_3():
    time_3 = datetime.datetime.strftime(datetime.datetime.now(), "%Y%m%d")
    return time_3




def random_six():
    random_six = ''.join(random.sample('0123456789', 6))
    return random_six

def random_cms():
    random_cms = ''.join(random.sample(
        ['0000275324', '0000087515', '0000060041', '0000001006', '0000001003', '0000001012', '0000001014', '0000001020',
         '0000001022', '0000001028', '0000001032', '0000001035', '0000001046', '0000001051', '0000001053', '0000001057',
         '0000001062', '0000001068', '0000001069', '0000001076', '0000001077', '0000001085', '0000001092', '0000001094',
         '0000001095', '0000001097', '0000001105', '0000001106', '0000001107', '0000001109', '0000001286', '0000001285',
         '0000001284', '0000001281', '0000001276', '0000001274', '0000001269', '0000001260', '0000001257'], 1))
    return random_cms
def random_cmsgwmc():
    random_cmsgwmc = ''.join(random.sample(
        ['中软国际董事局主席兼CEO', '副总监（主持工作）', 'CDT经理', '招聘副总裁', '集团副总裁', '集团总裁', '集团执行总裁', '招聘总裁', '总监', '事业部副总经理', '事业部总经理',
         '交付部经理', 'RDD副总裁', '业务部副总裁', '业务线副总裁', '业务群副总裁', '业务群总裁', '中软国际董事会执行委员会委员', '公司首席财务官CFO', '公司首席行政官CAO',
         '中软国际有限公司总裁', '中软国际有限公司副总裁', 'IIU总裁', 'IIU副总裁', 'RDD总裁', 'PDT经理', '招聘总裁', '招聘经理', '大区招聘经理'], 1))
    return random_cmsgwmc
def random_cmszj():
    random_cmszj = ''.join(
        random.sample(['9级', '10级', '11级', '16级', '19级', '20级', '21级', '23级', '25级', '29级', '30级'], 1))
    return random_cmszj
def random_cmsgwjb():
    random_cmsgwjb = ''.join(random.sample(['M1', 'M2', 'M3', 'M4', 'M5', 'M6'], 1))
    return random_cmsgwjb
def random_cmsdeptno():
    random_cmsdeptno = ''.join(random.sample(
        ['500031', '100011', '100065', '500060', '500021', '500054', '100010', '100012', '100020', '100021', '100023',
         '100024', '100025', '100026', '100035', '100036', '100037', '100038', '100045', '100046', '100047', '101006',
         '500147', '101007', '101008'], 1))
    return random_cmsdeptno
def time_cms():
    time_cms = datetime.datetime.strftime(datetime.datetime.now(), "%Y-%m-%d")
    return time_cms
def random_cmsxgbrma():
    random_cmsxgbrma = ''.join(random.sample(
        ['0000001012', '0000293837', '0000001077', '0000001069', '0000001068', '0000001109', '0000001107', '0000001105',
         '0000001094', '0000001097', '0000001085', '0000295525', '0000045451', '0000211377', '0000081042', '0000061667',
         '0000230702', '0000218807', '0000057965', '0000087331', '0000100308', '0000016880', '0000039419', '0000001191',
         '0000001717', '0000140384', '0000001646', '0000167514', '0000001014', '0000001020', '0000001022', '0000001028',
         '0000001032', '0000001035', '0000001046', '0000001051', '0000001053', '0000001057', '0000001062', '0000001068',
         '0000001069', '0000001076', '0000001077', '0000001085', '0000001092', '0000001094', '0000001095',
         '0000001097'], 1))
    return random_cmsxgbrma
def random_cmsxgbrmb():
    random_cmsxgbrmb = ''.join(random.sample(
        ['0000001057', '0000001053', '0000001051', '0000001201', '0000001085', '0000295525', '0000057965', '0000087331',
         '0000100308', '0000016880', '0000039419', '0000001191', '0000001717', '0000140384', '0000001646', '0000167514',
         '0000001014', '0000001020', '0000001105', '0000001106', '0000001107', '0000001109', '0000001286', '0000001285',
         '0000001284', '0000001281', '0000001276', '0000001274', '0000001269', '0000001260', '0000001257'], 1))
    return random_cmsxgbrmb
def random_cmsxgbrmc():
    random_cmsxgbrmc = ''.join(random.sample(
        ['0000230702', '0000001191', '0000001717', '0000140384', '0000001646', '0000075337', '0000256431', '0000009909',
         '0000238459', '0000238459', '0000013333', '0000001161', '0000246368', '0000126764', '0000097033', '0000169714',
         '0000148054', '0000201351', '0000018687', '0000002456'], 1))
    return random_cmsxgbrmc
def random_cmsxgbrmd():
    random_cmsxgbrmd = ''.join(random.sample(
        ['0000174825', '0000034740', '0000160632', '0000067688', '0000040111', '0000200210', '0000006235', '0000128466',
         '0000052901', '0000194007', '0000129331', '0000023911', '0000247336', '0000086076', '0000274133', '0000032399',
         '0000201164', '0000155487', '0000107230', '0000161927'], 1))
    return random_cmsxgbrmd

def time_xny():
    # 获取当前时间
    today = datetime.datetime.now()
    # 计算偏移量
    offset = datetime.timedelta(days=31)
    # 获取想要的日期的时间
    re_date = (today + offset).strftime('%Y-%m')
    return re_date

def id_card():
    try:
        chrome_options = Options()
        chrome_options.add_argument('--headless')
        # chrome_options.add_argument('--disable-gpu')
        # chrome_options.add_argument('--window-size=1920,1080')
        try:
            driver = webdriver.Chrome(r'C:\Users\lvshaobo\AppData\Local\Google\Chrome\Application\chromedriver.exe',chrome_options=chrome_options)
        except:
            driver = webdriver.Chrome(chrome_options=chrome_options)
        sleep(0.1)
        driver.get('http://www.chineseidcard.com/?region=110101&birthday=20000307&sex=1&num=5&r=36')
        sleep(1)
        driver.find_element_by_xpath('//button[@id="submit_btn"]').click()
        sleep(0.2)
        card_number = driver.find_element_by_xpath('/html/body/div/div[1]/div/div[2]/table[2]/tbody/tr[1]/td').text
        sleep(0.5)
        return card_number
    except:
        pass

    # bj()
# lj()
# sj()


# print(id_card())


#!/usr/bin/env python
# _*_ coding:utf-8 _*_
__author__ = 'jack'

import os


def new_report(testreport) -> object:
    """
    生成最新的测试报告文件
    :param testreport:
    :return:返回文件
    """
    lists = os.listdir(testreport)
    lists.sort(key=lambda fn: os.path.getmtime(testreport + "\\" + fn))
    file_new = os.path.join(testreport, lists[-1])
    return file_new







import datetime,random,time

from common_pims.lib.public import *

class Context:
    # pass
    time_1 = time_1()
    random_n = random_n()
    random_num = random_num()
    time_2 = time_2()
    random_nu = random_nu()
    random_nu1 = random_nu1()
    random_three=random_three()
    random_z =random_z()
    pems_random = pems_random()
    time_st = time_st()
    time_ots=time_ots()
    time_r = time_r()
    random_six =random_six()
    random_cms = random_cms()
    random_cmsgwmc =random_cmsgwmc()
    random_cmszj = random_cmszj()
    random_cmsgwjb = random_cmsgwjb()
    random_cmsdeptno = random_cmsdeptno()
    time_cms =time_cms()
    time_ny=time_ny()
    time_nyyc=time_nyyc()
    time_nyrsfmyc=time_nyrsfmyc()
    time_nyc=time_nyc()
    random_cmsxgbrma =random_cmsxgbrma()
    random_cmsxgbrmb =random_cmsxgbrmb()
    random_cmsxgbrmc =random_cmsxgbrmc()
    random_cmsxgbrmd =random_cmsxgbrmd()
    get_time_one=get_time_one()
    get_shijian_ten = get_shijian_ten()
    time_xny=time_xny()
    id_card = id_card()
    get_next_month_otherday=get_next_month_otherday()
    time_month=time_month()
    get_next_month=get_next_month()
    get_next2_month=get_next2_month()
    time_3=time_3()






import re
from common_pims.lib.Context import Context

class ReplaceVariable():

    def replace_varibale(params):
        try:
            if params.find("{{") != -1:
                list1 =  re.findall("{{(\w+)}}", params)

                # print(list[0])
                if len(list1)==1:
                    #params中查找到的值
                    i = list1[0]
                    #Context中对应i的值
                    replace_string = eval("Context.{0}".format(i))
                    # print(replace_string)
                    #替换后的内容
                    params = re.sub("{{(\w+)}}", replace_string, params)
                    #print(params)
                if len(list1)>1:
                    for i in list1:
                        # params中查找到的值
                        #print(i)
                        # Context中对应i的值
                        replace_string = eval("Context.{0}".format(i))
                        # print(replace_string)
                        # 替换后的内容
                        params = re.sub("{{"+i+"}}", replace_string, params)
                        #params = re.sub('{{|}}', '', params)
                        #print(params)

                else:
                    pass
                    #print('正则搜索为空')
            return params
        except:
            pass

    def random_1(params):
        try:
            if params.find("<<") != -1:
                list1 =  re.findall("<<(\w+)>>", params)
                # print(list1)

                # print(list[0])
                if len(list1)==1:
                    #params中查找到的值
                    i = list1[0]
                    #Context中对应i的值
                    try:
                        
                        replace_string = str(eval("Context.{0}".format(i)))
                    except:
                        replace_string = "Context.{0}".format(i)
                    
                    #print(replace_string)
                    #替换后的内容
                    params = re.sub("<<(\w+)>>", replace_string, params)
                    #print(params)
                if len(list1)>1:
                    for i in list1:
                        # params中查找到的值
                        #print(i)
                        # Context中对应i的值
                        replace_string = eval("Context.{0}".format(i))
                        # print(replace_string)
                        # 替换后的内容
                        params = re.sub("<<"+i+">>", replace_string, params)
                        #params = re.sub('{{|}}', '', params)
                        #print(params)

                else:
                    pass
                    #print('正则搜索为空')
            return params
        except:
            pass




#!/usr/bin/env python
#-*- coding:utf-8 -*-

from setuptools import setup, find_packages
from codecs import open
from os import path
import os
here = path.abspath(path.dirname(__file__))
#依赖文件
#requirement=open('requirements.txt').readline() 




setup(
    name='common_pims',
    version='1.0.0',
    description='common_pims',
    #long_description=str(open(path.join(here, "README.md")).read()),
    # The project's main homepage.
    url='',
    # Author details
    author='cxx',
    author_email='cuixiaoxia@chinasofti.com',
    # Choose your license
    license='',

	py_modules=["common_pims.lib.api","common_pims.lib.Context","common_pims.lib.cookie_ui","common_pims.lib.newReport","common_pims.lib.parsley","common_pims.lib.public","common_pims.lib.readexcel","common_pims.lib.ReplaceVariable","common_pims.lib.sendmail","common_pims.lib.writeexcel","common_pims.lib.utility","common_pims.package.HTMLTestRunner"],
	install_requires=["Appium-Python-Client==0.48",
	"adbutils==1.0.9",
    "apkutils2==1.0.0",
	"bleach==4.1.0",
	"cached-property==1.5.2",
	"cigam==0.0.3",
	"certifi==2021.5.30",
	"charset-normalizer==2.0.4",
	"colorama==0.4.4",
	"configparser==5.0.0",
	"decorator==5.1.1",
	"Deprecated==1.2.13",
	"deprecation==2.1.0",
	"DateTime==4.4",
	"ddt==1.3.1",
	"distlib==0.3.4",
	"document==1.0",
	"docutils==0.18.1",
	"et-xmlfile==1.0.1",
	"filelock==3.4.1",
	"facebook-wda==1.4.6",
	"idna==3.2",
	"importlib-metadata==4.8.3",
	"importlib-resources==5.4.0",
	"jdcal==1.4.1",
	"Jinja2==3.0.1",
	"keyring==23.4.1",
	"lxml==4.7.1",
	"logzero==1.7.0",
	"MarkupSafe==2.0.1",
	"meteo-downloader==1.0",
	"multi-key-dict==2.0.3",
	"multitasking==0.0.10",
	"nose==1.3.7",
	"nose-html-reporting==0.2.3",
	"numpy==1.19.5",
	"openpyxl==3.0.2",
	"packaging==21.3",
	"pandas==0.25.3",
	"pbr==5.8.1",
	"pkginfo==1.8.2",
	"platformdirs==2.4.0",
	"Pygments==2.11.2",
	"PyMySQL==1.0.2",
	"pyparsing==3.0.7",
	"python-dateutil==2.8.2",
	"pytz==2021.3",
	"pywin32-ctypes==0.2.0",
	"Pillow==8.4.0",
	"progress==1.6",
	"py==1.11.0",
	"PyAutoIt==0.6.5",
	"pyelftools==0.29",
	"PyYAML==6.0",
	"qiniu==7.5.0",
	"readme-renderer==32.0",
	"requests==2.26.0",
	"requests-toolbelt==0.9.1",
	"rfc3986==1.5.0",
	"retry==0.9.2",
	#"selenium==3.14.0",
	"six==1.16.0",
	"tqdm==4.62.3",
	"typing_extensions==4.1.1",
	"tornado==6.1",
	"upload==0.1.1",
	"urllib3==1.26.8",
	"virtualenv==20.13.1",
	"webencodings==0.5.1",
	"xlrd==1.2.0",
	"xlutils==2.0.0",
	"xlwt==1.3.0",
	"whichcraft==0.6.1",
	"wrapt==1.14.1",
	"xmltodict==0.13.0",
	"yfinance==0.1.70",
	"zipp==3.6.0",
	"zope.interface==5.4.0"
	
],  

)
#安装依赖：install_requires





#  setup.py各参数介绍：
#
# --name 包名称
#
# --version (-V) 包版本
#
# --author 程序的作者
#
# --author_email 程序的作者的邮箱地址
#
# --maintainer 维护者
#
# --maintainer_email 维护者的邮箱地址
#
# --url 程序的官网地址
#
# --license 程序的授权信息
#
# --description 程序的简单描述
#
# --long_description 程序的详细描述
#
# --platforms 程序适用的软件平台列表
#
# --classifiers 程序的所属分类列表
#
# --keywords 程序的关键字列表
#
# --packages 需要处理的包目录（包含__init__.py的文件夹）
#
# --py_modules 需要打包的python文件列表
# --download_url 程序的下载地址
#
# --cmdclass
#
# --data_files 打包时需要打包的数据文件，如图片，配置文件等
#
# --scripts 安装时需要执行的脚步列表
#
# --package_dir 告诉setuptools哪些目录下的文件被映射到哪个源码包。一个例子：package_dir = {'': 'lib'}，表示“root package”中的模块都在lib 目录中。
#
# --requires 定义依赖哪些模块
#
# --provides定义可以为哪些模块提供依赖
#
# --find_packages() 对于简单工程来说，手动增加packages参数很容易，刚刚我们用到了这个函数，它默认在和setup.py同一目录下搜索各个含有 __init__.py的包。


import requests
import os
import json
import re
from common_pims.lib.newReport import new_report
from common_pims.lib.public import *
from time import sleep


# cxx增加   2022.1.22修改
from commonchi.lib.sendmail import send_mail

#2021.1.22cxx1.24修改
def parsley(filename,cf,file_pa,codeBaseu,num=['0000275324']):
#def parsley(num,cf):
    file_url,file_url1= up_files(filename,file_pa)
    print(file_url)
    # print(file_url1)
    try:
        productName = cf.get("product_name", "product_name")
        timeu = get_shijianchuo_p()  # 运行时间
        contactName = cf.get("parsle", "contactName")  # 维护人
        num_result = int(cf.get("parsle", "num_result"))  # result在第几列
        totalCount = int(gain_excel_nrows(0, file_pa) - 1)
        #print(totalCount)
        passedCount = int(num_pa(file_pa, num_result))
        if totalCount == passedCount:
            result = 'PASS'
        else:
            result = 'FAIL'


        url = 'http://test.chinasoftinc.com:8423/parsley/api/gateway/send'
        par = {
            "Content-Type": "application/json",
            "module": "parsley",
            "method": "parsley/api/gateway/send",
            "rpcType": "http",
            "httpMethod": "post",
            "mannjuToken": "eyJhbGciOiJIUzI1NiJ9.eyJzdWIiOiLmnY7nkZ7pvpksd2VsaW5rLCs4Ni0xNTM5OTQxNDg2NCxFMTAwMDQ3MTE2IiwicGFzc3dvcmQiOiJ6cmdqXzAwMSIsImlkIjoiNjAwNTIzNCIsImlhdCI6MTY0MjEyMDA5OSwianRpIjoiNWYzOWNlZmUtMGVjOC00ZTY3LWE5ZGItNDU3MzMxNWFkODYwIiwidXNlcm5hbWUiOiLmnY7nkZ7pvpksd2VsaW5rLCs4Ni0xNTM5OTQxNDg2NCxFMTAwMDQ3MTE2In0.nLzQOjHOvxk2cOHoVfh91fEXy8cGHJNZlXCGmh0b6T0"
        }

        data = {
            "version": "1.0",
            "f_header": {
                "access_token": "wxfd9f5f0f4fa9fafd",
                "corp_uuid": "corp_1",
                "agent_uuid": "2f287992ea4d4b5384ca",
               # "scene_uuid": "24341dcf451e42789a75",
                "scene_uuid":"f384e3ff76cf45f5882b",
                "receiver_type": 1,
                "send_type": 2
            },
            "v_header": {
                "lob_numbers":num
                    #["0000275324"]
            },
            "payload": [
                # {
                #     "title": "API自动化测试结果提醒(点击查看百度网页）",
                #     "name": name,
                #     "urlType": "html",
                #     #"urlPath": 'http://localhost:63342/API/report/file_service/20220117134755.html?_ijt=okocmp0p5r4vnpogpu8pbjf4sb'
                #     "urlPath":"http://www.baidu.com"
                # }
                {

                    "title": "API自动化测试结果提醒",
                    "productName":productName,  #产品名称
                    "result":result,  #运行结果
                    "name":"",
                    "statistics":"【统计】",
                    "totalCount":totalCount ,  #合计数量
                    "passedCount":passedCount,  #passed数量
                    #"failedCoutn":int(num_fa(file_pa)),   #failed数量
                    "failedCoutn": totalCount-passedCount,
                    "coverage":'{:.2f}%'.format(passedCount/totalCount*100),  #百分比
                    "codeBase":"【代码仓库】",
                    "codeBaseu":codeBaseu,
                    "time":"【运行时间】",
                    "timeu":timeu,
                    "explain":"若结果有失败请尽快修复，确保在上线前无问题",
                    "contactName":contactName,
                    "report":"【点击查看报告详情】",
                    "urlType": "html",
                    # "urlPath": urlPath
                    # "urlPath": "http://192.168.1.7/api/20211130164559.html"
                    # "urlPath":"http://test.chinasoftinc.com:8527/filePreview?fileCode=fileId:NWZYUWxxUFE5ZzNQVnJYSGtlZjZuL1NaY2xrT255VjFSY2hJaHBwZmF6aUNzRHlQZkllN00ydmd1enJmV3dzcjBxNFNCWDVBdEhRMVN4U1luTHk1WWlQWHE1eHBHQlFwc1NXaHZUaWhSaFlINFMzZ1VoZGNNRWk4bkhZdWZEbkpKMmgvZFczNjlGUVBJRzJYeExQb3I1WmgxUXc2Y09oa24xc0lxZkNzdTcxQ0hSWU9WWHpEUmR6UlpLRUZhaVhKY1BrOERmYXdoa3g0SGdJUDRBeGNUY1B0ekR4cXdnbm51ZEtnYXdUcFhJWk4xeGdDaEpVNER3dEFiVWl0a2ZGTmsxSUZEbW1NUVNtTXZuamRrVGE5Sm11MWlld0w3M1NWK2kxSXdESHozS0R5UERDeHBEaEJsQ0V1WUFRYjdTZ2I2bi9kY09SNUtwOE9kdlpvcExDenR6WEdqa0pFR3BUa01HdXV4ZXM3TWl1MWo1VXNzWDA5ZHcrT3BWS241NEpWZEZxb3kzb0pKVkxhVXR6NW50UTBvQT09"
                    "urlPath": file_url
                }
            ]
        }
        rec = requests.post(url, params=par, json=data)
        print(rec.text)
        sleep(1)
    except:
        pass

def up_files(filename,file_pa):
    # url = 'http://test.chinasoftinc.com:8527/upload'
    url = 'http://117.78.32.21:31250/upload'
    data = {"filePath": "1000/1055/",
            "keySecret": "eyJwYXNzd29yZCI6IjEyMzQ1NiIsInBvcnQiOjYzNzksImhvc3QiOiJyZWRpczIuY3NpdC1hcHAuc3ZjLmNsdXN0ZXIubG9jYWwiLCJ1dWlkIjoiOTc3OGM0YTdmYWQxNDEzZmEwNDJmYTgwMzEwNGZjNzcifQ=="
            }
    # data = {"filePath": "1000/1031/",
    #         "keySecret": "eyJwYXNzd29yZCI6IiIsInBvcnQiOjYzNzksImhvc3QiOiJyZWRpczMuY3NpdC1hcHAuc3ZjLmNsdXN0ZXIubG9jYWwiLCJ1dWlkIjoiNjBkNjMwYWVkNDMwNDlmZTg0ZWRiZmJjMWMxY2VlMmYifQ=="
    #         }
    f = os.path.basename(filename)
    # print(f)
    name = f.split('.')
    # print(name[0])
    files_1 = {"file": (f, open(filename, 'rb'), "text/html")}
    res = requests.post(url=url, data=data, files=files_1)
    # print(res.text)
    ress = json.loads(res.text)
    # print(type(ress))
    res1 = ress['data']
    file_url = 'http://117.78.32.21:31250/filePreview?fileCode='+res1

    # f1 = os.path.basename(file_pa)
    # print(f1)
    # print(file_pa)
    files_2 = {
        "file": (name[0]+".xlsx", open(file_pa, 'rb'), "application/octet-stream")}
    # files_2 = {"file": (f1, open(file_pa, 'rb'), "application/octet-stream")}
    res = requests.post(url=url, data=data, files=files_2)
    # print(res.text)
    ress = json.loads(res.text)
    # print(type(ress))
    res2 = ress['data']
    file_url1 = 'http://117.78.32.21:31250/filePreview?fileCode=' + res2
    # print(file_url1)
    return file_url,file_url1

def get_data(tester,startTime,duration,status,success_count,failure_count,passrate):

    return tester, startTime, duration, status, success_count, failure_count, passrate












#
# import requests
# import os
#
# from commonchi.lib.newReport import new_report
# from commonchi.lib.public import *
# from time import sleep
#
#
# # cxx增加   2022.1.22修改
# from commonchi.lib.sendmail import send_mail
#
# #2021.1.22cxx1.24修改
# def parsley(cf,file_pa,codeBaseu,num=['0000275324']):
# #def parsley(num,cf):
#
#     try:
#         productName = cf.get("product_name", "product_name")
#         timeu = get_shijianchuo_p()  # 运行时间
#         contactName = cf.get("parsle", "contactName")  # 维护人
#         num_result = int(cf.get("parsle", "num_result"))  # result在第几列
#         totalCount = int(gain_excel_nrows(0, file_pa) - 1)
#         passedCount = int(num_pa(file_pa, num_result))
#         if totalCount == passedCount:
#             result = 'PASS'
#         else:
#             result = 'FAIL'
#
#
#         url = 'http://test.chinasoftinc.com:8423/parsley/api/gateway/send'
#         par = {
#             "Content-Type": "application/json",
#             "module": "parsley",
#             "method": "parsley/api/gateway/send",
#             "rpcType": "http",
#             "httpMethod": "post",
#             "mannjuToken": "eyJhbGciOiJIUzI1NiJ9.eyJzdWIiOiLmnY7nkZ7pvpksd2VsaW5rLCs4Ni0xNTM5OTQxNDg2NCxFMTAwMDQ3MTE2IiwicGFzc3dvcmQiOiJ6cmdqXzAwMSIsImlkIjoiNjAwNTIzNCIsImlhdCI6MTY0MjEyMDA5OSwianRpIjoiNWYzOWNlZmUtMGVjOC00ZTY3LWE5ZGItNDU3MzMxNWFkODYwIiwidXNlcm5hbWUiOiLmnY7nkZ7pvpksd2VsaW5rLCs4Ni0xNTM5OTQxNDg2NCxFMTAwMDQ3MTE2In0.nLzQOjHOvxk2cOHoVfh91fEXy8cGHJNZlXCGmh0b6T0"
#         }
#
#         data = {
#             "version": "1.0",
#             "f_header": {
#                 "access_token": "wxfd9f5f0f4fa9fafd",
#                 "corp_uuid": "corp_1",
#                 "agent_uuid": "2f287992ea4d4b5384ca",
#                # "scene_uuid": "24341dcf451e42789a75",
#                 "scene_uuid":"f384e3ff76cf45f5882b",
#                 "receiver_type": 1,
#                 "send_type": 2
#             },
#             "v_header": {
#                 "lob_numbers":num
#                     #["0000275324"]
#             },
#             "payload": [
#                 # {
#                 #     "title": "API自动化测试结果提醒(点击查看百度网页）",
#                 #     "name": name,
#                 #     "urlType": "html",
#                 #     #"urlPath": 'http://localhost:63342/API/report/file_service/20220117134755.html?_ijt=okocmp0p5r4vnpogpu8pbjf4sb'
#                 #     "urlPath":"http://www.baidu.com"
#                 # }
#                 {
#
#                     "title": "API自动化测试结果提醒",
#                     "productName":productName,  #产品名称
#                     "result":result,  #运行结果
#                     "name":"",
#                     "statistics":"【统计】",
#                     "totalCount":totalCount ,  #合计数量
#                     "passedCount":passedCount,  #passed数量
#                     #"failedCoutn":int(num_fa(file_pa)),   #failed数量
#                     "failedCoutn": totalCount-passedCount,
#                     "coverage":'{:.2f}%'.format(passedCount/totalCount*100),  #百分比
#                     "codeBase":"【代码仓库】",
#                     "codeBaseu":codeBaseu,
#                     "time":"【运行时间】",
#                     "timeu":timeu,
#                     "explain":"若结果有失败请尽快修复，确保在上线前无问题",
#                     "contactName":contactName,
#                     "report":"【点击查看报告详情】",
#                     # "urlType": "html",
#                     # "urlPath": urlPath
#                     #"urlPath": "http://192.168.1.7/api/20211130164559.html"
#                 }
#             ]
#         }
#         rec = requests.post(url, params=par, json=data)
#         print(rec.text)
#         sleep(1)
#     except:
#         pass




#!/usr/bin/env python 
# -*- coding:utf-8 -*-
from selenium import webdriver
from time import sleep
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver import ChromeOptions  #这个包用来规避被检测的风险

#pims test 非单点登录
def userlogin(url_c, username,pwd):
    #点击产品名称

    option = webdriver.ChromeOptions()
    option.add_argument('--no--sandbox')  # 沙箱机制
    option.add_argument('headless')  #无界面模式
    option.add_experimental_option('useAutomationExtension', False)
    option.add_experimental_option('excludeSwitches', ['enable-automation'])
    # driver=webdriver.Chrome(executable_path=driver_path,options=option)  #初始化路径，规避检测
    driver = webdriver.Chrome(options=option)
    # driver.excute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument"),{}

    driver.get(url_c)
    driver.maximize_window()
    sleep(0.3)
    driver.implicitly_wait(10)  # 如果网页没有加载完，避免出现加载超时的报错最多让他加载10秒
    driver.find_element_by_xpath("//*[@id='userName']").send_keys(username)
    driver.find_element_by_xpath("//*[@id='passWord']").send_keys(pwd)
    sleep(0.3)
    driver.find_element_by_xpath("//button[text()='登录']").click()
    sleep(0.5)
    driver.refresh()  # 刷新
    sleep(0.3)
    cookies = driver.get_cookies()  # 获取cookie信息
    sleep(0.3)
    srts = ".."
    # print(cookies)
    for cookie in cookies:
        srts = "%s'%s':'%s'," % (srts, cookie["name"], cookie["value"])
    srts=srts.replace('..', '')
    cookie=eval('{'+srts+'}')

    # print(cookie)
    return cookie

#
# url_c='http://prj.chinasoftinc.com/prj_test/index.jsp'
# username=2430
# pwd=123456
# userlogin(url_c, username,pwd)


#!/usr/bin/env python
# _*_ coding:utf-8 _*_
__author__ = 'jack'

import xlrd


class ReadExcel():
    """读取excel文件数据"""

    def __init__(self, fileName, SheetName="Sheet1"):
        self.data = xlrd.open_workbook(fileName)
        self.table = self.data.sheet_by_name(SheetName)

        # 获取总行数、总列数
        self.nrows = self.table.nrows
        self.ncols = self.table.ncols

    def read_data(self):
        if self.nrows > 1:
            # 获取第一行的内容，列表格式
            keys = self.table.row_values(0)
            listApiData = []
            # 获取每一行的内容，列表格式
            for col in range(1, self.nrows):
                values = self.table.row_values(col)
                # keys，values组合转换为字典
                api_dict = dict(zip(keys, values))
                listApiData.append(api_dict)
                # print(listApiData)
            return listApiData
        else:
            #print("表格是空数据!")
            return None


if __name__ == '__main__':
    Read = ReadExcel('D:\\Interface_automation\\DemoAPI-master\\file\\plugins框架API接口测试用例.xlsx')
    Read.read_data()


